@@ -2,10 +2,14 @@ package Test::Pretty;
 use strict;
 use warnings;
 use 5.008001;
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Test::Builder 0.82;
+
+# Conditionally load Windows Term encoding
+use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 use Term::Encoding ();
+
 use File::Spec ();
 use Term::ANSIColor ();
 use Test::More ();
@@ -182,7 +186,7 @@ sub _skip_all {
 
     $self->{Skip_All} = $self->parent ? $reason : 1;
 
-    printf("1..0 # SKIP %s\n", $reason);
+    $self->_print("1..0 # SKIP" . " $reason");
     $SHOW_DUMMY_TAP = 0;
     if ( $self->parent ) {
         die bless {} => 'Test::Builder::Exception';
