@@ -9,7 +9,9 @@ sub new {
     my $class = shift;
     my $arg_for = shift;
     $arg_for->{parser_class} = 'Test::Pretty::Parser';
-    return $class->SUPER::new($arg_for);
+    $arg_for->{switches} = ['-MTest::Pretty'];
+    my $self = $class->SUPER::new($arg_for);
+    return $self;
 }
 
 1;
